==> cas-service-domain-0.0.92-sources.jar: com/xforceplus/ultraman/app/casservice/metadata/PageMeta.java <==
package com.xforceplus.ultraman.app.casservice.metadata;

/**
 *
 * @author ultraman
 * @since 2024-01-06
 */

public class PageMeta {
    public interface SalesOrgnizationAffiliateInfoPage {
        static String code() {
            return "salesOrgnizationAffiliateInfoPage";
        }
        static String name() {
            return "销售组织附属信息页面";
        }
    }
    public interface RetailerSupplierMappingConfigRule {
        static String code() {
            return "retailerSupplierMappingConfigRule";
        }
        static String name() {
            return "零售商供应商映射配置规则";
        }
    }
    public interface SceneCodeAndSalesArchivesTypeMappingPage {
        static String code() {
            return "sceneCodeAndSalesArchivesTypeMappingPage";
        }
        static String name() {
            return "场景码销售档案分类关联关系";
        }
    }
    public interface PopSalesArchivesForPosOrderPage {
        static String code() {
            return "popSalesArchivesForPosOrderPage";
        }
        static String name() {
            return "销售档案POS单选择页面";
        }
    }
    public interface POS门店搜索 {
        static String code() {
            return "POS门店搜索";
        }
        static String name() {
            return "posStoreSearch";
        }
    }
    public interface ConfigRuleTemplatePage {
        static String code() {
            return "configRuleTemplatePage";
        }
        static String name() {
            return "配置规则模板页面";
        }
    }
    public interface PopSalesArchivesPage {
        static String code() {
            return "popSalesArchivesPage";
        }
        static String name() {
            return "销售档案订单选择页面";
        }
    }
    public interface RetailerSupplierMappingPage {
        static String code() {
            return "retailerSupplierMappingPage";
        }
        static String name() {
            return "零售商供应商映射关系页面";
        }
    }
    public interface SalesArchivesPage {
        static String code() {
            return "salesArchivesPage";
        }
        static String name() {
            return "销售档案页面";
        }
    }
}

==> cas-service-domain-0.0.218-sources.jar: com/xforceplus/ultraman/app/casservice/metadata/PageMeta.java <==
package com.xforceplus.ultraman.app.casservice.metadata;

/**
 *
 * @author ultraman
 * @since 2024-04-19
 */

public class PageMeta {
    public interface PopSalesArchivesPageOrg {
        static String code() {
            return "popSalesArchivesPageOrg";
        }
        static String name() {
            return "销售档案订单选择页面分公司";
        }
    }
    public interface PopSalesArchivesPageShip {
        static String code() {
            return "popSalesArchivesPageShip";
        }
        static String name() {
            return "销售档案订单选择页面送达方";
        }
    }
    public interface PopSalesArchivesForPosOrderPage {
        static String code() {
            return "popSalesArchivesForPosOrderPage";
        }
        static String name() {
            return "销售档案POS单选择页面";
        }
    }
    public interface POS门店搜索 {
        static String code() {
            return "POS门店搜索";
        }
        static String name() {
            return "posStoreSearch";
        }
    }
    public interface PurchaseOrgsNew {
        static String code() {
            return "purchaseOrgsNew";
        }
        static String name() {
            return "卖场门店基础数据";
        }
    }
    public interface SceneCodeAndSalesArchivesTypeMappingPage {
        static String code() {
            return "sceneCodeAndSalesArchivesTypeMappingPage";
        }
        static String name() {
            return "场景码销售档案分类关联关系";
        }
    }
    public interface PurchaserOrgsRetailerSupplierMapping {
        static String code() {
            return "purchaserOrgsRetailerSupplierMapping";
        }
        static String name() {
            return "卖场门店关联零售商供应商映射";
        }
    }
    public interface ConfigRuleTemplatePage {
        static String code() {
            return "configRuleTemplatePage";
        }
        static String name() {
            return "配置规则模板页面";
        }
    }
    public interface PopSalesArchivesPage {
        static String code() {
            return "popSalesArchivesPage";
        }
        static String name() {
            return "销售档案订单选择页面";
        }
    }
    public interface RetailerSupplierMappingConfigRule {
        static String code() {
            return "retailerSupplierMappingConfigRule";
        }
        static String name() {
            return "零售商供应商映射配置规则";
        }
    }
    public interface PopSalesArchivesPageSold {
        static String code() {
            return "popSalesArchivesPageSold";
        }
        static String name() {
            return "销售档案订单选择页面售达方";
        }
    }
    public interface SalesOrgnizationAffiliateInfoPage {
        static String code() {
            return "salesOrgnizationAffiliateInfoPage";
        }
        static String name() {
            return "销售组织附属信息页面";
        }
    }
    public interface PurchaseOrgs {
        static String code() {
            return "purchaseOrgs";
        }
        static String name() {
            return "卖场门店新客商";
        }
    }
    public interface RetailerSupplierMappingPage {
        static String code() {
            return "retailerSupplierMappingPage";
        }
        static String name() {
            return "零售商供应商映射关系页面";
        }
    }
    public interface SalesArchivesPage {
        static String code() {
            return "salesArchivesPage";
        }
        static String name() {
            return "销售档案页面";
        }
    }
    public interface PurchaserOrgsRetailerSupplierMappingPOS {
        static String code() {
            return "purchaserOrgsRetailerSupplierMappingPOS";
        }
        static String name() {
            return "卖场门店关联零售商供应商映射POS";
        }
    }
}
